==> jm17.0.zip: JM/lencod/inc/contributors.h <==

/*! \file
 *     contributors.h
 *  \brief
 *     List of contributors and copyright information.
 *
 *  \par Copyright statements
    \verbatim
   MPEG-4 AVC/H.264 JM coder/decoder

   Copyright (C) 2000/2009 by
   Apple Computer, Inc.
   Dolby Laboratories, Inc., USA
   Ericsson Radio Systems, Sweden
   Fraunhofer-Institute for Telecommunications Heinrich-Hertz-Institut (HHI), Germany
   LSI Logic, Canada
   Microsoft Corp., USA
   Motorola Inc., USA
   Nokia Corporation, Finland
   Nokia Inc., USA
   RealNetworks, Inc., USA
   Sejong Univ., Digital Media System Lab., Korea
   Siemens AG, Germany
   Telenor Broadband Services, Norway
   TELES AG, Germany
   Thomson, Inc., USA
   University of Hannover, Institut of Communication Theory and Signal Processing,Germany
   Videolocus, Canada

   \endverbatim
   \par Full Contact Information
   \verbatim

      Lowell Winger                   <lwinger@videolocus.com><lwinger@uwaterloo.ca><lwinger@lsil.com>
      Guy Ct                        <gcote@videolocus.com>
      Michael Gallant                 <mgallant@videolocus.com>
      VideoLocus Inc.
      97 Randall Dr.
      Waterloo, ON, Canada  N2V1C5

      Inge Lille-Langy               <inge.lille-langoy@telenor.com>
      Telenor Broadband Services
      P.O.Box 6914 St.Olavs plass
      N-0130 Oslo, Norway

      Rickard Sjoberg                 <rickard.sjoberg@era.ericsson.se>
      Ericsson Radio Systems
      KI/ERA/T/VV
      164 80 Stockholm, Sweden

      Stephan Wenger                  <stewe@cs.tu-berlin.de>
      TU Berlin / TELES AG
      Sekr. FR 6-3
      Franklinstr. 28-29
      D-10587 Berlin, Germany

      Jani Lainema                    <jani.lainema@nokia.com>
      Ragip Kurceren                  <ragip.kurceren@nokia.com>
      Nokia Inc. / Nokia Research Center
      6000 Connection Drive
      Irving, TX 75039, USA

      Miska M. Hannuksela             <miska.hannuksela@nokia.com>
      Nokia Corporation / Nokia Mobile Phones
      P.O. Box 88
      33721 Tampere, Finland

      Sebastian Purreiter             <sebastian.purreiter@mch.siemens.de>
      Siemens AG
      ICM MD MP RD MCH 83
      P.O.Box 80 17 07
      D-81617 Munich, Germany

      Thomas Wedi                     <wedi@tnt.uni-hannover.de>
      University of Hannover
      Institut of Communication Theory and Signal Processing
      Appelstr. 9a
      30167 Hannover

      Thomas Stockhammer              <stockhammer@ei.tum.de>
      Tobias Oelbaum (TO)             <drehvial@gmx.net>
      Institute for Communications Engineering
      Munich University of Technology
      80290 Munich
      Germany

      Yann Le Maguet                  <yann.lemaguet@philips.com>
      Philips Research France

      Dong Tian                       <tian@cs.tut.fi>
      Ye-Kui Wang                     <wyk@ieee.org>
      Tampere University of Technology
      Tampere International Center for Signal Processing
      33720 Tampere, Finland

      Karsten Suehring                <suehring@hhi.de>
      Heiko Schwarz                   <hschwarz@hhi.de>
      Detlev Marpe                    <marpe@hhi.de>
      Guido Heising
      Fraunhofer-Institute for Telecommunications
      Heinrich-Hertz-Institut (HHI)
      Einsteinufer 37
      10587 Berlin
      Germany

      Limin Wang                      <liwang@gi.com>
      Krit Panusopone                 <kpanusopone@gi.com>
      Rajeev Gandhi                   <rgandhi@gi.com>
      Yue Yu                          <yyu@gi.com>
      Motorola Inc.
      6450 Sequence Drive
      San Diego, CA 92121 USA

      Feng Wu                         <fengwu@microsoft.com>
      Xiaoyan Sun                     <sunxiaoyan@msrchina.research.microsoft.com>
      Microsoft Research Asia
      3/F, Beijing Sigma Center
      No.49, Zhichun Road, Hai Dian District,
      Beijing China 100080

      Mathias Wien                    <wien@ient.rwth-aachen.de>
      Achim Dahlhoff                  <dahlhoff@ient.rwth-aachen.de>
      Institut und Lehrstuhl fr Nachrichtentechnik
      RWTH Aachen University
      52072 Aachen
      Germany

      Yoshihiro Kikuchi               <yoshihiro.kikuchi@toshiba.co.jp>
      Takeshi Chujoh                  <takeshi.chujoh@toshiba.co.jp>
      Toshiba Corporation
      Research and Development Center
      Kawasaki 212-8582, Japan

      Shinya Kadono                   <kadono@drl.mei.co.jp>
      Matsushita Electric Industrial Co., Ltd.
      1006 Kadoma, Kadoma
      Osaka 663-8113, Japan

      Dzung Hoang                     <dthoang@yahoo.com>
      10533 Roy Butler Dr.
      Austin, TX 78717

      Eric Viscito                    <eric@ev-consulting.com>
      eV Consulting
      52 Tracy Ln
      Shelburne, VT 05482 USA

      Dzung Hoang                     <dzung.hoang@xilient.com>
      Xilient Inc.
      10181 Bubb Rd.
      Cupertino, CA 95014

      Barry Haskell
      Apple Computer, Inc.            <bhaskell@apple.com>
      2 Infinite Loop
      Cupertino, California 95014

      Greg Conklin
      RealNetworks, Inc.              <gregc@real.com>
      2601 Elliott Ave
      Seattle, WA 98101

      Jill Boyce                      <jill.boyce@thomson.net>
      Cristina Gomila                 <cristina.gomila@thomson.net>
      Thomson Inc
      2 Independence Way
      Princeton, NJ 08540

      Haoping Yu
      Corporate Research
      Thomson Inc
      101 West 103rd Street
      Indianapolis, IN 46290  

      Siwei Ma                        <swma@jdl.ac.cn>
      Institute of Computing Technology
      Chinese Academy of Sciences
      Kexueyuan South Road 6
      Haidian District
      Beijing, China

      Zhibo Chen                      <chenzhibo@tsinghua.org.cn>
      JianFeng Xu                     <fenax@video.mdc.tsinghua.edu.cn>
      Wenfang Fu                      <fwf@video.mdc.tsinghua.edu.cn>
      Dept.of E&E, Tsinghua Univ
      Haidian District
      Beijing China, 100084

      Alexis Michael Tourapis         <alexismt@ieee.org><atour@dolby.com>
      Athanasios Leontaris            <aleon@dolby.com>
      Peshala Pahalawatta             <ppaha@dolby.com>
      Yuwen He                        <yhe@dolby.com>  
	    Yan Ye                          <yye@dolby.com>      
      Dolby Laboratories Inc.
      3601 West Alameda Ave.
      Burbank, CA 91505

      Xiaoquan Yi                     <xyi@engr.scu.edu>
      Jun Zhang                       <jzhang2@engr.scu.edu>
      Dept. of C.E. Santa Clara Univ.
      500 El Camino Real
      Santa Clara, CA 95053

      Shun-ichi Sekiguchi             <Sekiguchi.Shunichi@eb.MitsubishiElectric.co.jp>
      Information Technology R&D Center, 
      Mitsubishi Electric Corporation
      5-1-1, Ofuna, Kamakura, Japan

      Yung-Lyul Lee                   <yllee@sejong.ac.kr>
      Ki-Hun Han                      <khhan@dms.sejong.ac.kr>
      Department of Computer Engineering, 
      Sejong University
      98 Kunja-Dong, Kwangjin-Gu, Seoul 143-747, Korea

   \endverbatim
 */

==> jm18.2.zip: JM/lencod/inc/contributors.h <==

/*! \file
 *     contributors.h
 *  \brief
 *     List of contributors and copyright information.
 *
 *  \par Copyright statements
    \verbatim
   MPEG-4 AVC/H.264 JM coder/decoder

   Copyright (C) 2000/2009 by
   Apple Computer, Inc.
   Dolby Laboratories, Inc., USA
   Ericsson Radio Systems, Sweden
   Fraunhofer-Institute for Telecommunications Heinrich-Hertz-Institut (HHI), Germany
   LSI Logic, Canada
   Microsoft Corp., USA
   Motorola Inc., USA
   Nokia Corporation, Finland
   Nokia Inc., USA
   RealNetworks, Inc., USA
   Sejong Univ., Digital Media System Lab., Korea
   Siemens AG, Germany
   Telenor Broadband Services, Norway
   TELES AG, Germany
   Thomson, Inc., USA
   University of Hannover, Institut of Communication Theory and Signal Processing,Germany
   Videolocus, Canada

   \endverbatim
   \par Full Contact Information
   \verbatim

      Lowell Winger                   <lwinger@videolocus.com><lwinger@uwaterloo.ca><lwinger@lsil.com>
      Guy Ct                        <gcote@videolocus.com>
      Michael Gallant                 <mgallant@videolocus.com>
      VideoLocus Inc.
      97 Randall Dr.
      Waterloo, ON, Canada  N2V1C5

      Inge Lille-Langy               <inge.lille-langoy@telenor.com>
      Telenor Broadband Services
      P.O.Box 6914 St.Olavs plass
      N-0130 Oslo, Norway

      Rickard Sjoberg                 <rickard.sjoberg@era.ericsson.se>
      Ericsson Radio Systems
      KI/ERA/T/VV
      164 80 Stockholm, Sweden

      Stephan Wenger                  <stewe@cs.tu-berlin.de>
      TU Berlin / TELES AG
      Sekr. FR 6-3
      Franklinstr. 28-29
      D-10587 Berlin, Germany

      Jani Lainema                    <jani.lainema@nokia.com>
      Ragip Kurceren                  <ragip.kurceren@nokia.com>
      Nokia Inc. / Nokia Research Center
      6000 Connection Drive
      Irving, TX 75039, USA

      Miska M. Hannuksela             <miska.hannuksela@nokia.com>
      Nokia Corporation / Nokia Mobile Phones
      P.O. Box 88
      33721 Tampere, Finland

      Sebastian Purreiter             <sebastian.purreiter@mch.siemens.de>
      Siemens AG
      ICM MD MP RD MCH 83
      P.O.Box 80 17 07
      D-81617 Munich, Germany

      Thomas Wedi                     <wedi@tnt.uni-hannover.de>
      University of Hannover
      Institut of Communication Theory and Signal Processing
      Appelstr. 9a
      30167 Hannover

      Thomas Stockhammer              <stockhammer@ei.tum.de>
      Tobias Oelbaum (TO)             <drehvial@gmx.net>
      Institute for Communications Engineering
      Munich University of Technology
      80290 Munich
      Germany

      Yann Le Maguet                  <yann.lemaguet@philips.com>
      Philips Research France

      Dong Tian                       <tian@cs.tut.fi>
      Ye-Kui Wang                     <wyk@ieee.org>
      Tampere University of Technology
      Tampere International Center for Signal Processing
      33720 Tampere, Finland

      Karsten Suehring                <Karsten.Suehring(at)hhi.fraunhofer.de>
      Heiko Schwarz
      Detlev Marpe
      Guido Heising
      Fraunhofer-Institute for Telecommunications
      Heinrich-Hertz-Institut (HHI)
      Einsteinufer 37
      10587 Berlin
      Germany

      Limin Wang                      <liwang@gi.com>
      Krit Panusopone                 <kpanusopone@gi.com>
      Rajeev Gandhi                   <rgandhi@gi.com>
      Yue Yu                          <yyu@gi.com>
      Motorola Inc.
      6450 Sequence Drive
      San Diego, CA 92121 USA

      Feng Wu                         <fengwu@microsoft.com>
      Xiaoyan Sun                     <sunxiaoyan@msrchina.research.microsoft.com>
      Microsoft Research Asia
      3/F, Beijing Sigma Center
      No.49, Zhichun Road, Hai Dian District,
      Beijing China 100080

      Mathias Wien                    <wien@ient.rwth-aachen.de>
      Achim Dahlhoff                  <dahlhoff@ient.rwth-aachen.de>
      Institut und Lehrstuhl fr Nachrichtentechnik
      RWTH Aachen University
      52072 Aachen
      Germany

      Yoshihiro Kikuchi               <yoshihiro.kikuchi@toshiba.co.jp>
      Takeshi Chujoh                  <takeshi.chujoh@toshiba.co.jp>
      Toshiba Corporation
      Research and Development Center
      Kawasaki 212-8582, Japan

      Shinya Kadono                   <kadono@drl.mei.co.jp>
      Matsushita Electric Industrial Co., Ltd.
      1006 Kadoma, Kadoma
      Osaka 663-8113, Japan

      Dzung Hoang                     <dthoang@yahoo.com>
      10533 Roy Butler Dr.
      Austin, TX 78717

      Eric Viscito                    <eric@ev-consulting.com>
      eV Consulting
      52 Tracy Ln
      Shelburne, VT 05482 USA

      Dzung Hoang                     <dzung.hoang@xilient.com>
      Xilient Inc.
      10181 Bubb Rd.
      Cupertino, CA 95014

      Barry Haskell
      Apple Computer, Inc.            <bhaskell@apple.com>
      2 Infinite Loop
      Cupertino, California 95014

      Greg Conklin
      RealNetworks, Inc.              <gregc@real.com>
      2601 Elliott Ave
      Seattle, WA 98101

      Jill Boyce                      <jill.boyce@thomson.net>
      Cristina Gomila                 <cristina.gomila@thomson.net>
      Thomson Inc
      2 Independence Way
      Princeton, NJ 08540

      Haoping Yu
      Corporate Research
      Thomson Inc
      101 West 103rd Street
      Indianapolis, IN 46290  

      Siwei Ma                        <swma@jdl.ac.cn>
      Institute of Computing Technology
      Chinese Academy of Sciences
      Kexueyuan South Road 6
      Haidian District
      Beijing, China

      Zhibo Chen                      <chenzhibo@tsinghua.org.cn>
      JianFeng Xu                     <fenax@video.mdc.tsinghua.edu.cn>
      Wenfang Fu                      <fwf@video.mdc.tsinghua.edu.cn>
      Dept.of E&E, Tsinghua Univ
      Haidian District
      Beijing China, 100084

      Alexis Michael Tourapis         <alexismt@ieee.org><atour@dolby.com>
      Athanasios Leontaris            <aleon@dolby.com>
      Peshala Pahalawatta             <ppaha@dolby.com>
      Yuwen He                        <yhe@dolby.com>  
      Yan Ye                          <yye@dolby.com>
      Dolby Laboratories Inc.
      3601 West Alameda Ave.
      Burbank, CA 91505

      Xiaoquan Yi                     <xyi@engr.scu.edu>
      Jun Zhang                       <jzhang2@engr.scu.edu>
      Dept. of C.E. Santa Clara Univ.
      500 El Camino Real
      Santa Clara, CA 95053

      Shun-ichi Sekiguchi             <Sekiguchi.Shunichi@eb.MitsubishiElectric.co.jp>
      Information Technology R&D Center, 
      Mitsubishi Electric Corporation
      5-1-1, Ofuna, Kamakura, Japan

      Yung-Lyul Lee                   <yllee@sejong.ac.kr>
      Ki-Hun Han                      <khhan@dms.sejong.ac.kr>
      Department of Computer Engineering, 
      Sejong University
      98 Kunja-Dong, Kwangjin-Gu, Seoul 143-747, Korea

   \endverbatim
 */
